@@ -24,96 +24,96 @@ our %servers = qw(
     ORG.RU	whois.ripn.net
     PP.RU	whois.ripn.net
     INT.RU  whois.int.ru    
-    RU.NET	whois.relcom.ru
+    RU.NET	whois.nic.ru
 
-    ABKHAZIA.SU         whois.relcom.ru
-    ADYGEYA.RU          whois.relcom.ru
-    ADYGEYA.SU          whois.relcom.ru
-    AKTYUBINSK.SU       whois.relcom.ru
-    AMURSK.RU           whois.relcom.ru
-    ARKHANGELSK.SU      whois.relcom.ru
-    ARMENIA.SU          whois.relcom.ru
-    ASHGABAD.SU         whois.relcom.ru
-    AZERBAIJAN.SU       whois.relcom.ru
-    BALASHOV.SU         whois.relcom.ru
-    BASHKIRIA.RU        whois.relcom.ru
-    BASHKIRIA.SU        whois.relcom.ru
-    BELGOROD.RU         whois.relcom.ru
-    BELGOROD.SU         whois.relcom.ru
-    BIR.RU              whois.relcom.ru
-    BRYANSK.SU          whois.relcom.ru
-    BUKHARA.SU          whois.relcom.ru
-    CBG.RU              whois.relcom.ru
-    CHELYABINSK.RU      whois.relcom.ru
-    CHIMKENT.SU         whois.relcom.ru
-    CMW.RU              whois.relcom.ru
-    DAGESTAN.RU         whois.relcom.ru
-    DAGESTAN.SU         whois.relcom.ru
-    DUDINKA.RU          whois.relcom.ru
-    EAST-KAZAKHSTAN.SU  whois.relcom.ru
-    EXNET.SU            whois.relcom.ru
-    FAREAST.RU          whois.relcom.ru
-    GEORGIA.SU          whois.relcom.ru
-    GROZNY.RU           whois.relcom.ru
-    GROZNY.SU           whois.relcom.ru
-    IVANOVO.SU          whois.relcom.ru
-    JAMBYL.SU           whois.relcom.ru
-    JAR.RU              whois.relcom.ru
-    JOSHKAR-OLA.RU      whois.relcom.ru
-    KALMYKIA.RU         whois.relcom.ru
-    KALMYKIA.SU         whois.relcom.ru
-    KALUGA.SU           whois.relcom.ru
-    KARACOL.SU          whois.relcom.ru
-    KARAGANDA.SU        whois.relcom.ru
-    KARELIA.SU          whois.relcom.ru
-    KCHR.RU             whois.relcom.ru
-    KHAKASSIA.SU        whois.relcom.ru
-    KOMI.SU             whois.relcom.ru
-    KRASNODAR.SU        whois.relcom.ru
-    KURGAN.SU           whois.relcom.ru
-    KUSTANAI.RU         whois.relcom.ru
-    KUSTANAI.SU         whois.relcom.ru
-    MANGYSHLAK.SU       whois.relcom.ru
-    MARINE.RU           whois.relcom.ru
-    MORDOVIA.RU         whois.relcom.ru
-    MORDOVIA.SU         whois.relcom.ru
-    MSK.RU              whois.relcom.ru
-    MSK.SU              whois.relcom.ru
-    MURMANSK.SU         whois.relcom.ru
-    MYTIS.RU            whois.relcom.ru
-    NALCHIK.RU          whois.relcom.ru
-    NALCHIK.SU          whois.relcom.ru
-    NAVOI.SU            whois.relcom.ru
+    ABKHAZIA.SU         whois.nic.ru
+    ADYGEYA.RU          whois.nic.ru
+    ADYGEYA.SU          whois.nic.ru
+    AKTYUBINSK.SU       whois.nic.ru
+    AMURSK.RU           whois.nic.ru
+    ARKHANGELSK.SU      whois.nic.ru
+    ARMENIA.SU          whois.nic.ru
+    ASHGABAD.SU         whois.nic.ru
+    AZERBAIJAN.SU       whois.nic.ru
+    BALASHOV.SU         whois.nic.ru
+    BASHKIRIA.RU        whois.nic.ru
+    BASHKIRIA.SU        whois.nic.ru
+    BELGOROD.RU         whois.nic.ru
+    BELGOROD.SU         whois.nic.ru
+    BIR.RU              whois.nic.ru
+    BRYANSK.SU          whois.nic.ru
+    BUKHARA.SU          whois.nic.ru
+    CBG.RU              whois.nic.ru
+    CHELYABINSK.RU      whois.nic.ru
+    CHIMKENT.SU         whois.nic.ru
+    CMW.RU              whois.nic.ru
+    DAGESTAN.RU         whois.nic.ru
+    DAGESTAN.SU         whois.nic.ru
+    DUDINKA.RU          whois.nic.ru
+    EAST-KAZAKHSTAN.SU  whois.nic.ru
+    EXNET.SU            whois.nic.ru
+    FAREAST.RU          whois.nic.ru
+    GEORGIA.SU          whois.nic.ru
+    GROZNY.RU           whois.nic.ru
+    GROZNY.SU           whois.nic.ru
+    IVANOVO.SU          whois.nic.ru
+    JAMBYL.SU           whois.nic.ru
+    JAR.RU              whois.nic.ru
+    JOSHKAR-OLA.RU      whois.nic.ru
+    KALMYKIA.RU         whois.nic.ru
+    KALMYKIA.SU         whois.nic.ru
+    KALUGA.SU           whois.nic.ru
+    KARACOL.SU          whois.nic.ru
+    KARAGANDA.SU        whois.nic.ru
+    KARELIA.SU          whois.nic.ru
+    KCHR.RU             whois.nic.ru
+    KHAKASSIA.SU        whois.nic.ru
+    KOMI.SU             whois.nic.ru
+    KRASNODAR.SU        whois.nic.ru
+    KURGAN.SU           whois.nic.ru
+    KUSTANAI.RU         whois.nic.ru
+    KUSTANAI.SU         whois.nic.ru
+    MANGYSHLAK.SU       whois.nic.ru
+    MARINE.RU           whois.nic.ru
+    MORDOVIA.RU         whois.nic.ru
+    MORDOVIA.SU         whois.nic.ru
+    MSK.RU              whois.nic.ru
+    MSK.SU              whois.nic.ru
+    MURMANSK.SU         whois.nic.ru
+    MYTIS.RU            whois.nic.ru
+    NALCHIK.RU          whois.nic.ru
+    NALCHIK.SU          whois.nic.ru
+    NAVOI.SU            whois.nic.ru
     NNOV.RU             whois.nnov.ru
-    NORILSK.RU          whois.relcom.ru
-    NORTH-KAZAKHSTAN.SU whois.relcom.ru
-    NOV.RU              whois.relcom.ru
-    NOV.SU              whois.relcom.ru
-    OBNINSK.SU          whois.relcom.ru
-    PALANA.RU           whois.relcom.ru
-    PENZA.SU            whois.relcom.ru
-    POKROVSK.SU         whois.relcom.ru
-    PYATIGORSK.RU       whois.relcom.ru
-    RU.NET              whois.relcom.ru
-    SIMBIRSK.RU         whois.relcom.ru
-    SOCHI.SU            whois.relcom.ru
-    SPB.RU              whois.relcom.ru
-    SPB.SU              whois.relcom.ru
-    TASHKENT.SU         whois.relcom.ru
-    TERMEZ.SU           whois.relcom.ru
-    TOGLIATTI.SU        whois.relcom.ru
-    TROITSK.SU          whois.relcom.ru
-    TSARITSYN.RU        whois.relcom.ru
-    TSELINOGRAD.SU      whois.relcom.ru
-    TULA.SU             whois.relcom.ru
-    TUVA.SU             whois.relcom.ru
-    VLADIKAVKAZ.RU      whois.relcom.ru
-    VLADIKAVKAZ.SU      whois.relcom.ru
-    VLADIMIR.RU         whois.relcom.ru
-    VLADIMIR.SU         whois.relcom.ru
-    VOLOGDA.SU          whois.relcom.ru
-    YAKUTIA.SU          whois.relcom.ru
-    YEKATERINBURG.RU    whois.relcom.ru
+    NORILSK.RU          whois.nic.ru
+    NORTH-KAZAKHSTAN.SU whois.nic.ru
+    NOV.RU              whois.nic.ru
+    NOV.SU              whois.nic.ru
+    OBNINSK.SU          whois.nic.ru
+    PALANA.RU           whois.nic.ru
+    PENZA.SU            whois.nic.ru
+    POKROVSK.SU         whois.nic.ru
+    PYATIGORSK.RU       whois.nic.ru
+    RU.NET              whois.nic.ru
+    SIMBIRSK.RU         whois.nic.ru
+    SOCHI.SU            whois.nic.ru
+    SPB.RU              whois.nic.ru
+    SPB.SU              whois.nic.ru
+    TASHKENT.SU         whois.nic.ru
+    TERMEZ.SU           whois.nic.ru
+    TOGLIATTI.SU        whois.nic.ru
+    TROITSK.SU          whois.nic.ru
+    TSARITSYN.RU        whois.nic.ru
+    TSELINOGRAD.SU      whois.nic.ru
+    TULA.SU             whois.nic.ru
+    TUVA.SU             whois.nic.ru
+    VLADIKAVKAZ.RU      whois.nic.ru
+    VLADIKAVKAZ.SU      whois.nic.ru
+    VLADIMIR.RU         whois.nic.ru
+    VLADIMIR.SU         whois.nic.ru
+    VOLOGDA.SU          whois.nic.ru
+    YAKUTIA.SU          whois.nic.ru
+    YEKATERINBURG.RU    whois.nic.ru
 
     NS     whois.nsiregistry.net
     RIPE   whois.ripe.net
@@ -475,7 +475,7 @@ our %notfound = (
     'whois.ripe.net'        => 'No entries found',
 
     'whois.ripn.net'        => 'No entries found',
-    'whois.relcom.ru'       => 'No entries found',
+    'whois.nic.ru'       => 'No entries found',
     'whois.nnov.ru'         => 'No entries found',
     'whois.int.ru'          => 'No entries found',
     'whois.reg.ru'          => '^Domain \S+ not found',
